# metamodel_version: 1.7.0
# version: 4.3.4
enum AffinityParameterEnum
  {
    pIC50
    pEC50
    pAC50
    pXC50
    pKi
    pKd
  }

enum AgentTypeEnum
  {
    manual_agent
    automated_agent
    data_analysis_pipeline
    computational_model
    text_mining_agent
    image_processing_agent
    manual_validation_of_automated_agent
    not_provided
  }

enum ApprovalStatusEnum
  {
    discovery_and_development_phase
    preclinical_research_phase
    fda_clinical_research_phase
    fda_review_phase_4
    fda_post_market_safety_review
    fda_clinical_research_phase_1
    fda_clinical_research_phase_2
    fda_clinical_research_phase_3
    fda_clinical_research_phase_4
    fda_fast_track
    fda_breakthrough_therapy
    fda_accelerated_approval
    fda_priority_review
    regular_fda_approval
    post_approval_withdrawal
  }

enum CausalMechanismQualifierEnum
  {
    modulation
    allosteric_modulation
    mixed_allosteric_modulation
    biphasic_allosteric_modulation
    mixed_agonism
    positive_modulation
    potentiation
    induction
    cofactor
    activation
    positive_allosteric_modulation
    agonism
    partial_agonism
    biased_agonism
    antibody_agonism
    molecular_channel_opening
    stimulation
    guanyl_nucleotide_exchange
    negative_modulation
    negative_gene_editing_modulation
    gtpase_activation
    atpase_activation
    antisense_oligonucleotide_inhibition
    rna_interference_inhibition
    suppression
    feedback_inhibition
    inhibition
    antibody_inhibition
    antagonism
    allosteric_antagonism
    non_competitive_antagonism
    competitive_inhibition
    noncompetitive_inhibition
    negative_allosteric_modulation
    gating_inhibition
    irreversible_inhibition
    molecular_channel_blockage
    inverse_agonism
    binding
    covalent_binding
    adduction
    crosslinking
    transglutamination
    disuphide_binding
    stabilization
    chaperone_mediated_stabilization
    destabilization
    degradation
    cleavage
    hydrolysis
    disruption
    opening
    multitarget_modulation
    chelation
    release
    sequestration
    oxidoreduction
    exogenous_protein
    exogenous_gene
    transcriptional_regulation
    translational_regulation
    catalytic_activity
    chemical_modification
    relocalization
    isomerization
    signaling_mediated_control
    immune_system_modulation
    vaccine_antigen
    post_transcriptional_regulation
    molecular_modification
    phosphorylation
    dephosphorylation
    neddylation
    deneddylation
    lipidation
    palmitoylation
    myristoylation
    tyrosination
    carboxylation
    ubiquitination
    monoubiquitination
    polyubiquitination
    deubiquitination
    sulfation
    reduction
    oxidation
    acetylation
    deacetylation
    glycosylation
    deglycosylation
    methylation
    trimethylation
    demethylation
    sumoylation
    desumoylation
    ADP__HYPHEN_MINUS__ribosylation
    de__HYPHEN_MINUS__ADP__HYPHEN_MINUS__ribosylation
    ampylation
    hydroxylation
    s_nitrosylation
  }

enum ChemicalEntityDerivativeEnum
  {
    metabolite
  }

enum ChemicalOrGeneOrGeneProductFormOrVariantEnum
  {
    genetic_variant_form
    modified_form
    loss_of_function_variant_form
    non_loss_of_function_variant_form
    gain_of_function_variant_form
    dominant_negative_variant_form
    polymorphic_form
    snp_form
    mutant_form
    analog_form
  }

enum ClinicalApprovalStatusEnum
  {
    approved_for_condition
    fda_approved_for_condition
    not_approved_for_condition
    post_approval_withdrawal
    off_label_use
    not_provided
  }

enum ClinicalTrialAgeStageEnum
  {
    adult
    child
    older_adult
  }

enum ClinicalTrialStatusEnum
  {
    ACTIVE_NOT_RECRUITING
    APPROVED_FOR_MARKETING
    AVAILABLE
    COMPLETED
    ENROLLING_BY_INVITATION
    NO_LONGER_AVAILABLE
    NOT_YET_RECRUITING
    RECRUITING
    SUSPENDED
    TEMPORARILY_NOT_AVAILABLE
    TERMINATED
    UNKNOWN
    WITHDRAWN
  }

enum DirectionQualifierEnum
  {
    increased
    upregulated
    decreased
    downregulated
  }

enum DrugAvailabilityEnum
  {
    over_the_counter
    prescription
  }

enum DrugDeliveryEnum
  {
    inhalation
    oral
    absorption_through_the_skin
    intravenous_injection
  }

enum DruggableGeneCategoryEnum
  {
    tclin
    tbio
    tchem
    tdark
  }

enum FDAIDAAdverseEventEnum
  {
    life_threatening_adverse_event
    serious_adverse_event
    suspected_adverse_reaction
    unexpected_adverse_event
  }

enum GeneOrGeneProductOrChemicalEntityAspectEnum
  {
    activity_or_abundance
    abundance
    activity
    expression
    synthesis
    degradation
    cleavage
    hydrolysis
    metabolic_processing
    mutation_rate
    stability
    folding
    localization
    transport
    absorption
    aggregation
    interaction
    release
    isomerization
    secretion
    uptake
    splicing
    molecular_interaction
    guanyl_nucleotide_exchange
    adenyl_nucleotide_exchange
    molecular_modification
    acetylation
    acylation
    alkylation
    amination
    carbamoylation
    ethylation
    glutathionylation
    glycation
    glycosylation
    glucuronidation
    n_linked_glycosylation
    o_linked_glycosylation
    hydroxylation
    lipidation
    farnesylation
    geranoylation
    myristoylation
    palmitoylation
    prenylation
    methylation
    nitrosation
    nucleotidylation
    phosphorylation
    ribosylation
    ADP__HYPHEN_MINUS__ribosylation
    sulfation
    sumoylation
    ubiquitination
    oxidation
    reduction
    carboxylation
  }

enum GeneOrGeneProductOrChemicalPartQualifierEnum
  {
    __3_prime_utr
    __5_prime_utr
    polya_tail
    promoter
    enhancer
    exon
    intron
  }

enum KnowledgeLevelEnum
  {
    knowledge_assertion
    logical_entailment
    prediction
    statistical_association
    observation
    not_provided
  }

enum LogicalInterpretationEnum
  {
    some_some
    all_some
    inverse_all_some
  }

enum PhaseEnum
  {
    __0
    __1
    __2
  }

enum ReactionDirectionEnum
  {
    left_to_right
    right_to_left
    bidirectional
    neutral
  }

enum ReactionSideEnum
  {
    left
    right
  }

enum ResearchPhaseEnum
  {
    pre_clinical_research_phase
    clinical_trial_phase
    clinical_trial_phase_1
    clinical_trial_phase_1_to_2
    clinical_trial_phase_2
    clinical_trial_phase_2_to_3
    clinical_trial_phase_3
    clinical_trial_phase_4
    not_provided
  }

enum ResourceRoleEnum
  {
    primary_knowledge_source
    aggregator_knowledge_source
    supporting_data_source
  }

enum ResponseEnum
  {
    therapeutic_response
    negative
  }

enum ResponseTargetEnum
  {
    cohort
    cell_line
    individual
    sample
  }

enum SequenceEnum
  {
    na
    aa
  }

enum StrandEnum
  {
    __PLUS_SIGN__
    __HYPHEN_MINUS__
    __FULL_STOP__
    __QUESTION_MARK__
  }

type AccessibleDnaRegion implements GenomicEntity, ChemicalEntityOrGeneOrGeneProduct, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type Activity implements ActivityAndBehavior
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

interface ActivityAndBehavior
  {
  }

interface AdministrativeEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type Agent
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    affiliation: [Uriorcurie]
    address: String
    id: String!
    name: LabelType
  }

type AnatomicalEntity implements PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

interface AnatomicalEntityToAnatomicalEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: AnatomicalEntity!
    object: AnatomicalEntity!
  }

type AnatomicalEntityToAnatomicalEntityOntogenicAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: AnatomicalEntity!
    object: AnatomicalEntity!
    predicate: PredicateType!
  }

type AnatomicalEntityToAnatomicalEntityPartOfAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: AnatomicalEntity!
    object: AnatomicalEntity!
    predicate: PredicateType!
  }

interface Annotation
  {
  }

type Article
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
    publishedIn: Uriorcurie!
    isoAbbreviation: String
    volume: String
    issue: String
  }

type Association
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
  }

type Attribute implements OntologyClass
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type Bacterium
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type Behavior implements OntologyClass, ActivityAndBehavior
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type BehaviorToBehavioralFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: Behavior!
    object: BehavioralFeature!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type BehavioralExposure
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
  }

type BehavioralFeature
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    inheritance: GeneticInheritance
  }

type BehavioralOutcome implements Outcome
  {
  }

type BiologicalEntity implements ThingWithTaxon
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type BiologicalProcess implements Occurrent, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type BiologicalProcessOrActivity implements Occurrent, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type BiologicalProcessOrActivityToAnatomicalEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: BiologicalProcessOrActivity!
    object: AnatomicalEntity!
  }

type BiologicalProcessOrActivityToBiologicalProcessOrActivityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: BiologicalProcessOrActivity!
    object: BiologicalProcessOrActivity!
    predicate: PredicateType!
  }

type BiologicalProcessOrActivityToGeneOrGeneProductOrGeneFamilyAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: BiologicalProcessOrActivity!
    object: GeneOrGeneProductOrGeneFamily!
    predicate: PredicateType!
  }

type BiologicalSex
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type BioticExposure
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
  }

type Book
  {
    iri: IriType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    name: LabelType
    id: String!
    type: [String]
  }

type BookChapter
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
    publishedIn: Uriorcurie!
    volume: String
    chapter: String
  }

type Case implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
    hasBiologicalSex: BiologicalSex
  }

type CaseToDiseaseAssociation implements CaseToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: NamedThing!
    predicate: PredicateType!
    object: Disease!
    onsetQualifier: Onset
  }

interface CaseToEntityAssociationMixin
  {
    subject: Case!
    predicate: PredicateType!
    object: NamedThing!
  }

type CaseToGeneAssociation implements CaseToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: NamedThing!
    predicate: PredicateType!
    object: GeneOrGeneProduct!
  }

type CaseToPhenotypicFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin, CaseToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    negated: Boolean
    onsetQualifier: Onset
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type CaseToVariantAssociation implements CaseToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: NamedThing!
    predicate: PredicateType!
    object: SequenceVariant!
    hasZygosity: Zygosity
  }

type CausalGeneToDiseaseAssociation implements GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    allelicRequirement: String
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    subject: GeneOrGeneProduct!
    object: Disease!
  }

type Cell
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type CellLine implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type CellLineAsAModelOfDiseaseAssociation implements ModelToDiseaseAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    diseaseContextQualifier: Disease
    subjectSpecializationQualifier: Uriorcurie
    objectSpecializationQualifier: Uriorcurie
    anatomicalContextQualifier: String
    subject: CellLine!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
  }

type CellLineToDiseaseOrPhenotypicFeatureAssociation implements CellLineToEntityAssociationMixin, EntityToDiseaseOrPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: DiseaseOrPhenotypicFeature!
    diseaseContextQualifier: Disease
    subjectSpecializationQualifier: Uriorcurie
    objectSpecializationQualifier: Uriorcurie
    anatomicalContextQualifier: String
  }

interface CellLineToEntityAssociationMixin
  {
    subject: CellLine!
    predicate: PredicateType!
    object: NamedThing!
  }

type CellularComponent
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type CellularOrganism implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type ChemicalAffectsBiologicalEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    subjectDerivativeQualifier: ChemicalEntityDerivativeEnum
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    subjectContextQualifier: AnatomicalEntity
    subjectDirectionQualifier: DirectionQualifierEnum
    objectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    objectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    objectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectContextQualifier: AnatomicalEntity
    objectDirectionQualifier: DirectionQualifierEnum
    causalMechanismQualifier: CausalMechanismQualifierEnum
    anatomicalContextQualifier: AnatomicalEntity
    qualifiedPredicate: String
    speciesContextQualifier: OrganismTaxon
    subject: ChemicalEntity!
    predicate: PredicateType!
    object: BiologicalEntity!
  }

type ChemicalAffectsGeneAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    subjectDerivativeQualifier: ChemicalEntityDerivativeEnum
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    subjectContextQualifier: AnatomicalEntity
    subjectDirectionQualifier: DirectionQualifierEnum
    objectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    objectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    objectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectContextQualifier: AnatomicalEntity
    objectDirectionQualifier: DirectionQualifierEnum
    causalMechanismQualifier: CausalMechanismQualifierEnum
    anatomicalContextQualifier: AnatomicalEntity
    qualifiedPredicate: String
    speciesContextQualifier: OrganismTaxon
    subject: ChemicalEntity!
    predicate: PredicateType!
    object: BiologicalEntity!
  }

type ChemicalEntity implements PhysicalEssence, ChemicalOrDrugOrTreatment, ChemicalEntityOrGeneOrGeneProduct, ChemicalEntityOrProteinOrPolypeptide
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
  }

type ChemicalEntityAssessesNamedThingAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: ChemicalEntity!
    object: NamedThing!
    predicate: PredicateType!
  }

interface ChemicalEntityOrGeneOrGeneProduct
  {
  }

type ChemicalEntityOrGeneOrGeneProductRegulatesGeneAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    objectDirectionQualifier: DirectionQualifierEnum
    predicate: PredicateType!
    subject: ChemicalEntityOrGeneOrGeneProduct!
    object: GeneOrGeneProduct!
  }

interface ChemicalEntityOrProteinOrPolypeptide
  {
  }

interface ChemicalEntityToEntityAssociationMixin
  {
    subject: ChemicalEntityOrGeneOrGeneProduct!
    predicate: PredicateType!
    object: NamedThing!
  }

type ChemicalExposure
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
    hasQuantitativeValue: [QuantityValue]
  }

type ChemicalGeneInteractionAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    subjectDerivativeQualifier: ChemicalEntityDerivativeEnum
    subjectContextQualifier: AnatomicalEntity
    objectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    objectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    objectContextQualifier: AnatomicalEntity
    anatomicalContextQualifier: AnatomicalEntity
    subject: ChemicalEntity!
    object: GeneOrGeneProduct!
    predicate: PredicateType!
  }

type ChemicalMixture implements OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: String
    highestFDAApprovalStatus: ApprovalStatusEnum
    drugRegulatoryStatusWorldWide: ApprovalStatusEnum
    routesOfDelivery: [DrugDeliveryEnum]
  }

interface ChemicalOrDrugOrTreatment
  {
  }

type ChemicalOrDrugOrTreatmentSideEffectDiseaseOrPhenotypicFeatureAssociation implements EntityToDiseaseOrPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    fDAAdverseEventLevel: FDAIDAAdverseEventEnum
    diseaseContextQualifier: Disease
    subjectSpecializationQualifier: Uriorcurie
    objectSpecializationQualifier: Uriorcurie
    anatomicalContextQualifier: String
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    predicate: PredicateType!
  }

type ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation implements EntityToDiseaseOrPhenotypicFeatureAssociationMixin, EntityToFeatureOrDiseaseQualifiersMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    fDAAdverseEventLevel: FDAIDAAdverseEventEnum
    predicate: PredicateType!
    diseaseContextQualifier: Disease
    subjectSpecializationQualifier: Uriorcurie
    objectSpecializationQualifier: Uriorcurie
    anatomicalContextQualifier: String
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
  }

type ChemicalRole
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type ChemicalToChemicalAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: NamedThing!
    predicate: PredicateType!
    object: ChemicalEntity!
    speciesContextQualifier: OrganismTaxon
  }

type ChemicalToChemicalDerivationAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    speciesContextQualifier: OrganismTaxon
    catalystQualifier: [MacromolecularMachineMixin]
    subject: ChemicalEntity!
    object: ChemicalEntity!
    predicate: PredicateType!
  }

type ChemicalToDiseaseOrPhenotypicFeatureAssociation implements EntityToDiseaseOrPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    object: DiseaseOrPhenotypicFeature!
    diseaseContextQualifier: Disease
    subjectSpecializationQualifier: Uriorcurie
    objectSpecializationQualifier: Uriorcurie
    anatomicalContextQualifier: String
  }

interface ChemicalToEntityAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
  }

type ChemicalToPathwayAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: ChemicalEntity!
    object: Pathway!
  }

type ChiSquaredAnalysisResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type ClinicalAttribute
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type ClinicalCourse
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type ClinicalEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type ClinicalFinding
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    inheritance: GeneticInheritance
    hasAttribute: [ClinicalAttribute]
  }

type ClinicalIntervention
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type ClinicalMeasurement
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
    hasAttributeType: OntologyClass!
  }

type ClinicalModifier
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type ClinicalTrial
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    hasStudyResults: [StudyResult]
    clinicalTrialPhase: ResearchPhaseEnum
    clinicalTrialPrimaryPurpose: String
    clinicalTrialInterventionModel: String
    clinicalTrialOverallStatus: ClinicalTrialStatusEnum
    clinicalTrialBriefTitle: String
    clinicalTrialEnrollmentType: String
    clinicalTrialStartDate: Date
    clinicalTrialEnrollment: Integer
    clinicalTrialAgeStage: ClinicalTrialAgeStageEnum
    clinicalTrialAgeRange: String
    clinicalTrialTestedIntervention: String
    clinicalTrialInterventions: [ClinicalIntervention]
    clinicalTrialConditions: [DiseaseOrPhenotypicFeature]
    creationDate: Date
  }

type CodingSequence implements GenomicEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type Cohort implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type CommonDataElement
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type ComplexChemicalExposure
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
  }

type ComplexMolecularMixture
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: String
    highestFDAApprovalStatus: ApprovalStatusEnum
    drugRegulatoryStatusWorldWide: ApprovalStatusEnum
    routesOfDelivery: [DrugDeliveryEnum]
  }

type ConceptCountAnalysisResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type ConfidenceLevel
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type ContributorAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: InformationContentEntity!
    predicate: PredicateType!
    object: Agent!
    qualifiers: [OntologyClass]
  }

type CorrelatedGeneToDiseaseAssociation implements EntityToDiseaseAssociationMixin, GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    allelicRequirement: String
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    zScore: Float
    subject: GeneOrGeneProduct!
    object: Disease!
    predicate: PredicateType!
  }

type Dataset
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type DatasetDistribution
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    distributionDownloadUrl: String
  }

type DatasetSummary
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    sourceWebPage: String
    sourceLogo: String
  }

type DatasetVersion
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    hasDataset: Dataset
    ingestDate: String
    hasDistribution: DatasetDistribution
  }

type Device
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type DiagnosticAid
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type Disease
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    inheritance: GeneticInheritance
  }

type DiseaseAssociatedWithResponseToChemicalEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    responseContextQualifier: ResponseEnum
    responseTargetContextQualifier: ResponseTargetEnum
    subject: Disease!
    object: ChemicalEntity!
    predicate: PredicateType!
  }

type DiseaseOrPhenotypicFeature implements OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    inheritance: GeneticInheritance
  }

type DiseaseOrPhenotypicFeatureExposure implements PathologicalEntityMixin
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
  }

type DiseaseOrPhenotypicFeatureOutcome implements Outcome
  {
  }

interface DiseaseOrPhenotypicFeatureToEntityAssociationMixin
  {
    subject: DiseaseOrPhenotypicFeature!
    predicate: PredicateType!
    object: NamedThing!
  }

type DiseaseOrPhenotypicFeatureToGeneticInheritanceAssociation implements DiseaseOrPhenotypicFeatureToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    predicate: PredicateType!
    object: GeneticInheritance!
  }

type DiseaseOrPhenotypicFeatureToLocationAssociation implements DiseaseOrPhenotypicFeatureToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    object: AnatomicalEntity!
  }

interface DiseaseToEntityAssociationMixin
  {
    subject: Disease!
    predicate: PredicateType!
    object: NamedThing!
  }

type DiseaseToExposureEventAssociation implements DiseaseToEntityAssociationMixin, EntityToExposureEventAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
  }

type DiseaseToPhenotypicFeatureAssociation implements FrequencyQuantifier, EntityToPhenotypicFeatureAssociationMixin, DiseaseToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    onsetQualifier: Onset
    subject: Disease!
    object: PhenotypicFeature!
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
  }

type Drug implements ChemicalOrDrugOrTreatment, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: String
    highestFDAApprovalStatus: ApprovalStatusEnum
    drugRegulatoryStatusWorldWide: ApprovalStatusEnum
    routesOfDelivery: [DrugDeliveryEnum]
  }

type DrugExposure
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
    hasQuantitativeValue: [QuantityValue]
  }

type DrugLabel
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
  }

interface DrugToEntityAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
  }

type DrugToGeneAssociation implements DrugToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    object: GeneOrGeneProduct!
  }

type DrugToGeneInteractionExposure implements GeneGroupingMixin
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
    hasQuantitativeValue: [QuantityValue]
    hasGeneOrGeneProduct: [Gene]
  }

type DruggableGeneToDiseaseAssociation implements EntityToDiseaseAssociationMixin, GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    allelicRequirement: String
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    object: Disease!
    subject: GeneOrGeneProduct!
    predicate: PredicateType!
    hasEvidence: [DruggableGeneCategoryEnum]
  }

type Edge
  {
  }

interface Entity
  {
    id: String!
    iri: IriType
    category: [Uriorcurie]
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
  }

type EntityToDiseaseAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    clinicalApprovalStatus: ClinicalApprovalStatusEnum
    maxResearchPhase: ResearchPhaseEnum
  }

interface EntityToDiseaseAssociationMixin
  {
    frequencyQualifier: FrequencyValue
    subject: NamedThing!
    predicate: PredicateType!
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    object: Disease!
  }

interface EntityToDiseaseOrPhenotypicFeatureAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: DiseaseOrPhenotypicFeature!
    diseaseContextQualifier: Disease
    subjectSpecializationQualifier: Uriorcurie
    objectSpecializationQualifier: Uriorcurie
    anatomicalContextQualifier: String
  }

interface EntityToExposureEventAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: ExposureEvent!
  }

interface EntityToFeatureOrDiseaseQualifiersMixin
  {
    frequencyQualifier: FrequencyValue
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
  }

interface EntityToFeatureOrGeneQualifiersMixin
  {
    frequencyQualifier: FrequencyValue
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
  }

interface EntityToFeatureOrVariantQualifiersMixin
  {
    frequencyQualifier: FrequencyValue
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
  }

interface EntityToOutcomeAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: Outcome!
  }

type EntityToPhenotypicFeatureAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    clinicalApprovalStatus: ClinicalApprovalStatusEnum
    maxResearchPhase: ResearchPhaseEnum
  }

type EntityToPhenotypicFeatureAssociationMixin implements FrequencyQuantifier
  {
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    subject: NamedThing!
    predicate: PredicateType!
    object: PhenotypicFeature!
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type EnvironmentalExposure
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
  }

type EnvironmentalFeature
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type EnvironmentalFoodContaminant
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
  }

type EnvironmentalProcess implements Occurrent
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type EpidemiologicalOutcome implements Outcome
  {
  }

interface EpigenomicEntity
  {
    hasBiologicalSequence: BiologicalSequence
  }

type Event
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type EvidenceType
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type Exon
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type ExonToTranscriptRelationship
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: Exon!
    object: Transcript!
  }

type ExposureEvent implements OntologyClass
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
  }

type ExposureEventToOutcomeAssociation implements EntityToOutcomeAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    populationContextQualifier: PopulationOfIndividualOrganisms
    temporalContextQualifier: TimeType
  }

type ExposureEventToPhenotypicFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: ExposureEvent!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

interface FeatureOrDiseaseQualifiersToEntityMixin
  {
    frequencyQualifier: FrequencyValue
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
  }

type Food
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: String
    highestFDAApprovalStatus: ApprovalStatusEnum
    drugRegulatoryStatusWorldWide: ApprovalStatusEnum
    routesOfDelivery: [DrugDeliveryEnum]
  }

type FoodAdditive
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
  }

interface FrequencyQualifierMixin
  {
    frequencyQualifier: FrequencyValue
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
  }

interface FrequencyQuantifier
  {
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type FunctionalAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: MacromolecularMachineMixin!
    object: OntologyClass!
  }

type Fungus
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type Gene implements GeneOrGeneProduct, GenomicEntity, ChemicalEntityOrGeneOrGeneProduct, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    symbol: String
    xref: [Uriorcurie]
    hasBiologicalSequence: BiologicalSequence
  }

type GeneAffectsChemicalAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    subjectDerivativeQualifier: String
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    subjectContextQualifier: AnatomicalEntity
    subjectDirectionQualifier: DirectionQualifierEnum
    objectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    objectPartQualifier: GeneOrGeneProductOrChemicalPartQualifierEnum
    objectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectContextQualifier: AnatomicalEntity
    objectDirectionQualifier: DirectionQualifierEnum
    objectDerivativeQualifier: ChemicalEntityDerivativeEnum
    causalMechanismQualifier: CausalMechanismQualifierEnum
    anatomicalContextQualifier: AnatomicalEntity
    qualifiedPredicate: String
    speciesContextQualifier: OrganismTaxon
    subject: GeneOrGeneProduct!
    predicate: PredicateType!
    object: ChemicalEntity!
  }

type GeneAsAModelOfDiseaseAssociation implements ModelToDiseaseAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    allelicRequirement: String
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    object: Disease!
    subject: GeneOrGeneProduct!
  }

interface GeneExpressionMixin
  {
    quantifierQualifier: OntologyClass
    expressionSite: AnatomicalEntity
    stageQualifier: LifeStage
    phenotypicState: DiseaseOrPhenotypicFeature
  }

type GeneFamily implements GeneGroupingMixin, ChemicalEntityOrGeneOrGeneProduct
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasGeneOrGeneProduct: [Gene]
  }

type GeneFamilyToGeneOrGeneProductOrGeneFamilyAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: Gene!
    object: GeneFamily!
    predicate: PredicateType!
  }

interface GeneGroupingMixin
  {
    hasGeneOrGeneProduct: [Gene]
  }

type GeneHasVariantThatContributesToDiseaseAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    allelicRequirement: String
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    subjectFormOrVariantQualifier: String
    subject: GeneOrGeneProduct!
    object: Disease!
    predicate: PredicateType!
  }

interface GeneOrGeneProduct
  {
    name: SymbolType
  }

interface GeneOrGeneProductOrGeneFamily
  {
  }

type GeneOrGeneProductOrGeneFamilyToAnatomicalEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: GeneOrGeneProductOrGeneFamily!
    object: AnatomicalEntity!
  }

type GeneOrGeneProductOrGeneFamilyToBiologicalProcessOrActivityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: GeneOrGeneProductOrGeneFamily!
    object: BiologicalProcessOrActivity!
    predicate: PredicateType!
  }

interface GeneProductIsoformMixin
  {
    name: SymbolType
    synonym: [LabelType]
    xref: [Uriorcurie]
  }

interface GeneProductMixin
  {
    name: SymbolType
    synonym: [LabelType]
    xref: [Uriorcurie]
  }

type GeneRegulatesGeneAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    objectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum!
    objectDirectionQualifier: DirectionQualifierEnum!
    qualifiedPredicate: String!
    speciesContextQualifier: OrganismTaxon
    subject: GeneOrGeneProduct!
    predicate: PredicateType!
    object: GeneOrGeneProduct!
  }

type GeneToDiseaseAssociation implements GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    allelicRequirement: String
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    subject: GeneOrGeneProduct!
    object: Disease!
  }

type GeneToDiseaseOrPhenotypicFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin, GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    allelicRequirement: String
    subject: GeneOrGeneProduct!
    object: DiseaseOrPhenotypicFeature!
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

interface GeneToEntityAssociationMixin
  {
    subject: GeneOrGeneProduct!
    predicate: PredicateType!
    object: NamedThing!
  }

type GeneToExpressionSiteAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    stageQualifier: LifeStage
    quantifierQualifier: OntologyClass
    objectSpecializationQualifier: Uriorcurie
    subject: GeneOrGeneProduct!
    object: AnatomicalEntity!
    predicate: PredicateType!
  }

interface GeneToGeneAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: GeneOrGeneProduct!
    object: GeneOrGeneProduct!
  }

type GeneToGeneCoexpressionAssociation implements GeneExpressionMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: GeneOrGeneProduct!
    object: GeneOrGeneProduct!
    predicate: PredicateType!
    quantifierQualifier: OntologyClass
    expressionSite: AnatomicalEntity
    stageQualifier: LifeStage
    phenotypicState: DiseaseOrPhenotypicFeature
  }

type GeneToGeneFamilyAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: Gene!
    object: GeneFamily!
    predicate: PredicateType!
  }

type GeneToGeneHomologyAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: GeneOrGeneProduct!
    predicate: PredicateType!
    object: GeneOrGeneProduct!
  }

type GeneToGeneProductRelationship
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: Gene!
    object: GeneProductMixin!
    predicate: PredicateType!
  }

type GeneToGoTermAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: Gene!
    object: OntologyClass!
  }

type GeneToPathwayAssociation implements GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: GeneOrGeneProduct!
    object: Pathway!
  }

type GeneToPhenotypicFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin, GeneToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subjectFormOrVariantQualifier: ChemicalOrGeneOrGeneProductFormOrVariantEnum
    subjectAspectQualifier: GeneOrGeneProductOrChemicalEntityAspectEnum
    objectDirectionQualifier: DirectionQualifierEnum
    allelicRequirement: String
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    subject: GeneOrGeneProduct!
    object: PhenotypicFeature!
  }

type GeneticInheritance
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type Genome implements GenomicEntity, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type GenomicBackgroundExposure implements GeneGroupingMixin, PhysicalEssence, GenomicEntity, ThingWithTaxon, OntologyClass
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
    hasGeneOrGeneProduct: [Gene]
    hasBiologicalSequence: BiologicalSequence
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

interface GenomicEntity
  {
    hasBiologicalSequence: BiologicalSequence
  }

type GenomicSequenceLocalization
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    startInterbaseCoordinate: Integer
    endInterbaseCoordinate: Integer
    genomeBuild: StrandEnum
    strand: StrandEnum
    phase: PhaseEnum
    subject: NucleicAcidEntity!
    object: NucleicAcidEntity!
    predicate: PredicateType!
  }

type Genotype implements PhysicalEssence, GenomicEntity, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasZygosity: Zygosity
    hasBiologicalSequence: BiologicalSequence
  }

type GenotypeAsAModelOfDiseaseAssociation implements ModelToDiseaseAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    predicate: PredicateType!
    object: NamedThing!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    subject: Genotype!
  }

type GenotypeToDiseaseAssociation implements GenotypeToEntityAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
  }

interface GenotypeToEntityAssociationMixin
  {
    subject: Genotype!
    predicate: PredicateType!
    object: NamedThing!
  }

type GenotypeToGeneAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    predicate: PredicateType!
    subject: Genotype!
    object: Gene!
  }

type GenotypeToGenotypePartAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    predicate: PredicateType!
    subject: Genotype!
    object: Genotype!
  }

type GenotypeToPhenotypicFeatureAssociation implements EntityToPhenotypicFeatureAssociationMixin, GenotypeToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    predicate: PredicateType!
    subject: Genotype!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type GenotypeToVariantAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    predicate: PredicateType!
    subject: Genotype!
    object: SequenceVariant!
  }

type GenotypicSex
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type GeographicExposure
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
  }

type GeographicLocation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    latitude: Float
    longitude: Float
  }

type GeographicLocationAtTime
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    latitude: Float
    longitude: Float
    timepoint: TimeType
  }

type GrossAnatomicalStructure
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type Haplotype implements GenomicEntity, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type Hospitalization
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type HospitalizationOutcome implements Outcome
  {
  }

type Human implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type IceesStudyResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    chiSquaredStatistic: Float
    chiSquaredDof: Integer
    chiSquaredP: Float
    totalSampleSize: Integer
    fisherExactOddsRatio: Float
    fisherExactP: Float
    logOddsRatio: Float
    logOddsRatio95Ci: [Float]
  }

type IndividualOrganism implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

interface InformationContentEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type InformationContentEntityToNamedThingAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: NamedThing!
    object: NamedThing!
    predicate: PredicateType!
  }

type Invertebrate
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type JournalArticle
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
    publishedIn: Uriorcurie!
    isoAbbreviation: String
    volume: String
    issue: String
  }

interface KnowledgeGraph
  {
    nodes: [Entity]
    edges: [Association]
  }

type KnowledgeGraph
  {
    nodes: [Entity]
    edges: [Association]
  }

type LifeStage implements OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type LogOddsAnalysisResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type MacromolecularComplex implements MacromolecularMachineMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

interface MacromolecularMachineMixin
  {
    name: SymbolType
  }

type MacromolecularMachineToBiologicalProcessAssociation implements MacromolecularMachineToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: MacromolecularMachineMixin!
    object: BiologicalProcess!
    speciesContextQualifier: OrganismTaxon
  }

type MacromolecularMachineToCellularComponentAssociation implements MacromolecularMachineToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: MacromolecularMachineMixin!
    object: CellularComponent!
    speciesContextQualifier: OrganismTaxon
  }

interface MacromolecularMachineToEntityAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    speciesContextQualifier: OrganismTaxon
  }

type MacromolecularMachineToMolecularActivityAssociation implements MacromolecularMachineToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: MacromolecularMachineMixin!
    object: MolecularActivity!
    speciesContextQualifier: OrganismTaxon
  }

type Mammal implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

interface MappingCollection
  {
    predicateMappings: [PredicateMapping]
  }

type MaterialSample implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type MaterialSampleDerivationAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: MaterialSample!
    predicate: PredicateType!
    object: NamedThing!
  }

type MaterialSampleToDiseaseOrPhenotypicFeatureAssociation implements MaterialSampleToEntityAssociationMixin, EntityToDiseaseOrPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    diseaseContextQualifier: Disease
    subjectSpecializationQualifier: Uriorcurie
    objectSpecializationQualifier: Uriorcurie
    anatomicalContextQualifier: String
  }

interface MaterialSampleToEntityAssociationMixin
  {
    subject: MaterialSample!
    predicate: PredicateType!
    object: NamedThing!
  }

type MicroRNA
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

interface ModelToDiseaseAssociationMixin
  {
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
  }

type MolecularActivity implements Occurrent, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [MolecularEntity]
    hasOutput: [MolecularEntity]
    enabledBy: [MacromolecularMachineMixin]
  }

type MolecularActivityToChemicalEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: MolecularActivity!
    object: ChemicalEntity!
  }

type MolecularActivityToMolecularActivityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: MolecularActivity!
    object: MolecularActivity!
  }

type MolecularActivityToPathwayAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: MolecularActivity!
    object: Pathway!
    predicate: PredicateType!
  }

type MolecularEntity implements OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isMetabolite: Boolean
  }

type MolecularMixture
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: String
    highestFDAApprovalStatus: ApprovalStatusEnum
    drugRegulatoryStatusWorldWide: ApprovalStatusEnum
    routesOfDelivery: [DrugDeliveryEnum]
  }

type MortalityOutcome implements Outcome
  {
  }

type NamedThing
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type NamedThingAssociatedWithLikelihoodOfNamedThingAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: NamedThing!
    subjectAspectQualifier: String
    subjectContextQualifier: OntologyClass
    predicate: PredicateType!
    object: NamedThing!
    objectAspectQualifier: String
    objectContextQualifier: OntologyClass
    populationContextQualifier: PopulationOfIndividualOrganisms
  }

type Node
  {
  }

type NoncodingRNAProduct
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type NucleicAcidEntity implements GenomicEntity, ThingWithTaxon, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isMetabolite: Boolean
    hasBiologicalSequence: BiologicalSequence
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type NucleicAcidSequenceMotif
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type NucleosomeModification implements GeneProductIsoformMixin, GenomicEntity, EpigenomicEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type ObservedExpectedFrequencyAnalysisResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

interface Occurrent
  {
  }

type Onset
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

interface OntologyClass
  {
    id: String!
  }

type OrganismAttribute
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type OrganismTaxon
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    hasTaxonomicRank: TaxonomicRank
  }

interface OrganismTaxonToEntityAssociation
  {
    subject: OrganismTaxon!
    predicate: PredicateType!
    object: NamedThing!
  }

type OrganismTaxonToEnvironmentAssociation implements OrganismTaxonToEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: OrganismTaxon!
    object: NamedThing!
    predicate: PredicateType!
  }

type OrganismTaxonToOrganismTaxonAssociation implements OrganismTaxonToEntityAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: OrganismTaxon!
    object: OrganismTaxon!
  }

type OrganismTaxonToOrganismTaxonInteraction
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    associatedEnvironmentalContext: String
    subject: OrganismTaxon!
    object: OrganismTaxon!
    predicate: PredicateType!
  }

type OrganismTaxonToOrganismTaxonSpecialization
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: OrganismTaxon!
    object: OrganismTaxon!
    predicate: PredicateType!
  }

type OrganismToOrganismAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: IndividualOrganism!
    object: IndividualOrganism!
  }

type OrganismalEntity implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type OrganismalEntityAsAModelOfDiseaseAssociation implements ModelToDiseaseAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: OrganismalEntity!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
  }

interface Outcome
  {
  }

type PairwiseGeneToGeneInteraction
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: GeneOrGeneProduct!
    object: GeneOrGeneProduct!
    predicate: PredicateType!
  }

type PairwiseMolecularInteraction
  {
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    interactingMoleculesCategory: OntologyClass
    subject: MolecularEntity!
    id: String!
    predicate: PredicateType!
    object: MolecularEntity!
  }

type Patent
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
  }

interface PathognomonicityQuantifier
  {
  }

type PathologicalAnatomicalExposure
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
  }

type PathologicalAnatomicalOutcome implements Outcome
  {
  }

type PathologicalAnatomicalStructure implements PathologicalEntityMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

interface PathologicalEntityMixin
  {
  }

type PathologicalProcess implements PathologicalEntityMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type PathologicalProcessExposure
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
  }

type PathologicalProcessOutcome implements Outcome
  {
  }

type Pathway implements OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type Phenomenon implements Occurrent
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type PhenotypicFeature
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    inheritance: GeneticInheritance
  }

type PhenotypicFeatureToDiseaseAssociation implements EntityToDiseaseAssociationMixin, PhenotypicFeatureToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    predicate: PredicateType!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type PhenotypicFeatureToEntityAssociationMixin implements FrequencyQuantifier
  {
    frequencyQualifier: FrequencyValue
    predicate: PredicateType!
    object: NamedThing!
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    subject: PhenotypicFeature!
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type PhenotypicFeatureToPhenotypicFeatureAssociation implements PhenotypicFeatureToEntityAssociationMixin, EntityToPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
    diseaseContextQualifier: Disease
  }

type PhenotypicQuality
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type PhenotypicSex
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type PhysicalEntity implements PhysicalEssence
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

interface PhysicalEssence
  {
  }

interface PhysicalEssenceOrOccurrent
  {
  }

type PhysiologicalProcess implements OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasInput: [NamedThing]
    hasOutput: [NamedThing]
    enabledBy: [PhysicalEntity]
  }

type PlanetaryEntity
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type Plant
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type Polypeptide implements ChemicalEntityOrGeneOrGeneProduct, ChemicalEntityOrProteinOrPolypeptide
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type PopulationOfIndividualOrganisms implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type PopulationToPopulationAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: PopulationOfIndividualOrganisms!
    object: PopulationOfIndividualOrganisms!
    predicate: PredicateType!
  }

type PosttranslationalModification implements GeneProductIsoformMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type PredicateMapping
  {
    mappedPredicate: String
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    subjectFormOrVariantQualifier: String
    subjectPartQualifier: String
    subjectDerivativeQualifier: String
    subjectContextQualifier: String
    predicate: PredicateType!
    qualifiedPredicate: String
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    objectFormOrVariantQualifier: String
    objectPartQualifier: String
    objectDerivativeQualifier: String
    objectContextQualifier: String
    causalMechanismQualifier: CausalMechanismQualifierEnum
    anatomicalContextQualifier: String
    speciesContextQualifier: OrganismTaxon
    exactMatch: [NamedThing]
    narrowMatch: [NamedThing]
    broadMatch: [NamedThing]
  }

type PreprintPublication
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
  }

type Procedure implements ActivityAndBehavior
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
  }

type ProcessRegulatesProcessAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: BiologicalProcess!
    predicate: PredicateType!
    object: BiologicalProcess!
  }

type ProcessedMaterial
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isSupplement: String
    highestFDAApprovalStatus: ApprovalStatusEnum
    drugRegulatoryStatusWorldWide: ApprovalStatusEnum
    routesOfDelivery: [DrugDeliveryEnum]
  }

type Protein implements GeneProductMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type ProteinDomain implements GeneGroupingMixin, ChemicalEntityOrGeneOrGeneProduct
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasGeneOrGeneProduct: [Gene]
  }

type ProteinFamily implements GeneGroupingMixin, ChemicalEntityOrGeneOrGeneProduct
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasGeneOrGeneProduct: [Gene]
  }

type ProteinIsoform implements GeneProductIsoformMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type Publication
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
  }

type QuantityValue
  {
    hasUnit: Unit
    hasNumericValue: Double
  }

type ReactionToCatalystAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    predicate: PredicateType!
    speciesContextQualifier: OrganismTaxon
    stoichiometry: Integer
    reactionDirection: ReactionDirectionEnum
    reactionSide: ReactionSideEnum
    subject: MolecularEntity!
    object: GeneOrGeneProduct!
  }

type ReactionToParticipantAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    predicate: PredicateType!
    object: ChemicalEntity!
    speciesContextQualifier: OrganismTaxon
    stoichiometry: Integer
    reactionDirection: ReactionDirectionEnum
    reactionSide: ReactionSideEnum
    subject: MolecularEntity!
  }

type ReagentTargetedGene implements GenomicEntity, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type RegulatoryRegion implements GenomicEntity, ChemicalEntityOrGeneOrGeneProduct, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

interface RelationshipQuantifier
  {
  }

type RelationshipType
  {
    id: String!
  }

type RelativeFrequencyAnalysisResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type RetrievalSource
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    resourceId: Uriorcurie!
    resourceRole: ResourceRoleEnum!
    upstreamResourceIds: [Uriorcurie]
    sourceRecordUrls: [Uriorcurie]
    xref: [Uriorcurie]
  }

type RNAProduct implements GeneProductMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type RNAProductIsoform implements GeneProductIsoformMixin
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

interface SensitivityQuantifier
  {
  }

type SequenceAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
  }

type SequenceFeatureRelationship
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: NucleicAcidEntity!
    object: NucleicAcidEntity!
  }

type SequenceVariant implements GenomicEntity, PhysicalEssence, OntologyClass
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasGene: [Gene]
    hgvsNomenclature: [String]
    hasBiologicalSequence: BiologicalSequence
    id: String!
  }

interface SequenceVariantModulatesTreatmentAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: SequenceVariant!
    object: Treatment!
  }

type Serial
  {
    iri: IriType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    name: LabelType
    isoAbbreviation: String
    volume: String
    issue: String
    id: String!
    type: [String]
  }

type SeverityValue
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type SiRNA
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type SmallMolecule
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    tradeName: String
    availableFrom: [DrugAvailabilityEnum]
    maxToleratedDose: String
    isToxic: Boolean
    hasChemicalRole: [ChemicalRole]
    isMetabolite: Boolean
  }

type Snv
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasGene: [Gene]
    hgvsNomenclature: [String]
    hasBiologicalSequence: BiologicalSequence
    id: String!
  }

type SocioeconomicAttribute
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }

type SocioeconomicExposure
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
    hasAttribute: [SocioeconomicAttribute]!
  }

type SocioeconomicOutcome implements Outcome
  {
  }

interface SpecificityQuantifier
  {
  }

type Study
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    hasStudyResults: [StudyResult]
  }

type StudyPopulation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

interface StudyResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

type StudyVariable
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
  }

interface SubjectOfInvestigation
  {
  }

type TaxonToTaxonAssociation
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: OrganismTaxon!
    object: OrganismTaxon!
  }

type TaxonomicRank
  {
    id: String!
  }

type TextMiningStudyResult
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    supportingText: [String]
    subjectLocationInText: [Integer]
    objectLocationInText: [Integer]
    extractionConfidenceScore: Integer
    supportingDocumentType: String
    supportingDocumentYear: Integer
    supportingTextSectionType: String
  }

interface ThingWithTaxon
  {
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type Transcript
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
  }

type TranscriptToGeneRelationship
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: Transcript!
    object: Gene!
  }

type TranscriptionFactorBindingSite implements GenomicEntity, ChemicalEntityOrGeneOrGeneProduct, PhysicalEssence, OntologyClass
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasBiologicalSequence: BiologicalSequence
  }

type Treatment implements ChemicalOrDrugOrTreatment
  {
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    timepoint: TimeType
    exposureType: String
    exposureVehicle: String
    exposureRoute: String
    exposureStartAge: Integer
    exposureEndAge: Integer
    exposureDuration: Time
    exposureMagnitude: String
    exposureAdditionalCondition: String
    id: String!
    hasDrug: [Drug]
    hasDevice: [Device]
    hasProcedure: [Procedure]
  }

type VariantAsAModelOfDiseaseAssociation implements ModelToDiseaseAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    predicate: PredicateType!
    object: NamedThing!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    subject: SequenceVariant!
  }

type VariantToDiseaseAssociation implements VariantToEntityAssociationMixin, EntityToDiseaseAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: NamedThing!
    predicate: PredicateType!
    object: NamedThing!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
  }

interface VariantToEntityAssociationMixin
  {
    subject: SequenceVariant!
    predicate: PredicateType!
    object: NamedThing!
  }

type VariantToGeneAssociation implements VariantToEntityAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    object: Gene!
    predicate: PredicateType!
  }

type VariantToGeneExpressionAssociation implements GeneExpressionMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    subject: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    object: Gene!
    predicate: PredicateType!
    quantifierQualifier: OntologyClass
    expressionSite: AnatomicalEntity
    stageQualifier: LifeStage
    phenotypicState: DiseaseOrPhenotypicFeature
  }

type VariantToPhenotypicFeatureAssociation implements VariantToEntityAssociationMixin, EntityToPhenotypicFeatureAssociationMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    object: NamedThing!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: SequenceVariant!
    frequencyQualifier: FrequencyValue
    subjectAspectQualifier: String
    subjectDirectionQualifier: DirectionQualifierEnum
    objectAspectQualifier: String
    objectDirectionQualifier: DirectionQualifierEnum
    qualifiedPredicate: String
    diseaseContextQualifier: Disease
    sexQualifier: BiologicalSex
    hasCount: Integer
    hasTotal: Integer
    hasQuotient: Double
    hasPercentage: Double
  }

type VariantToPopulationAssociation implements VariantToEntityAssociationMixin, FrequencyQuantifier, FrequencyQualifierMixin
  {
    id: String!
    iri: IriType
    name: LabelType
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    predicate: PredicateType!
    negated: Boolean
    qualifier: String
    qualifiers: [OntologyClass]
    publications: [Publication]
    sources: [RetrievalSource]
    hasEvidence: [EvidenceType]
    knowledgeSource: String
    primaryKnowledgeSource: String
    aggregatorKnowledgeSource: [String]
    knowledgeLevel: KnowledgeLevelEnum!
    agentType: AgentTypeEnum!
    timepoint: TimeType
    originalSubject: String
    originalPredicate: Uriorcurie
    originalObject: String
    subjectFeatureName: String
    objectFeatureName: String
    subjectCategory: OntologyClass
    objectCategory: OntologyClass
    subjectClosure: [String]
    objectClosure: [String]
    subjectCategoryClosure: [OntologyClass]
    objectCategoryClosure: [OntologyClass]
    subjectNamespace: String
    objectNamespace: String
    subjectLabelClosure: [String]
    objectLabelClosure: [String]
    retrievalSourceIds: [RetrievalSource]
    pValue: Float
    adjustedPValue: Float
    hasSupportingStudies: [Study]
    updateDate: Date
    hasConfidenceScore: Float
    type: [String]
    category: [Uriorcurie]
    subject: SequenceVariant!
    object: PopulationOfIndividualOrganisms!
    hasQuotient: Double
    hasCount: Integer
    hasTotal: Integer
    hasPercentage: Double
    frequencyQualifier: FrequencyValue
  }

type Vertebrate
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type Virus implements SubjectOfInvestigation
  {
    id: String!
    iri: IriType
    type: [String]
    name: LabelType
    description: NarrativeText
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    inTaxon: [OrganismTaxon]
    inTaxonLabel: LabelType
    hasAttribute: [Attribute]
  }

type WebPage
  {
    iri: IriType
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    license: String
    rights: String
    format: String
    creationDate: Date
    authors: [Agent]
    pages: [String]
    summary: String
    keywords: [String]
    meshTerms: [Uriorcurie]
    xref: [Uriorcurie]
    publicationType: [String]!
    id: String!
    name: LabelType
  }

type Zygosity
  {
    id: String!
    type: [String]
    description: NarrativeText
    hasAttribute: [Attribute]
    deprecated: Boolean
    providedBy: [String]
    xref: [Uriorcurie]
    fullName: LabelType
    synonym: [LabelType]
    equivalentIdentifiers: [Uriorcurie]
    informationContent: Float
    taxon: Uriorcurie
    category: [Uriorcurie]!
    name: LabelType
    hasAttributeType: OntologyClass!
    hasQuantitativeValue: [QuantityValue]
    hasQualitativeValue: NamedThing
    iri: IriType
  }
